@@ -3,3 +3,5 @@ from .keypointnet_loss import KeypointNetLoss
 from .segmentation import DiceLoss
 from .segmentation import FocalLoss
 from .segmentation import JaccardLoss
+from .segmentation import WeightedReconstruction
+from .segmentation import WeightedReconstructionWithError
